# TTSLab 🔬

Run TTS models. Think ComfyUI but for TTS.

## Installation

```bash
pip install ttslab
```

## Usage

```bash
ttslab serve
```

Starts up a web UI.

## Models

You can install models from the official model index (coming soon):

```bash
ttslab install ttslab/f5-tts # currently does not work
```

Or you can install models from a Git repository:

```bash
ttslab install https://github.com/ttslab-project/f5-tts
```

Or you can install models from a local directory:

```bash
ttslab install ./f5-tts --local
```

## Tips

### Running out of disk space?

You can delete the `~/.ttslab` directory to free up space.

### Uninstall TTSLab

```bash
pip uninstall ttslab
rm -rf ~/.ttslab
```


## License

This project is licensed under the BSD-3-Clause license. See the LICENSE file for details.